
# Filter out private python and php libs. Does not work on EPEL5,
# therefor we use it conditionally
%{?filter_setup:
%filter_provides_in %{python2_sitearch}/.*\.so$
%filter_provides_in %{php_extdir}/.*\.so$
%filter_setup
}

%if 0%{?fedora} > 24
# FTBFS on rawhide -- rex
%global with_php 0
%else
%global with_php 1
%endif

Name:           libkolab
Version:        1.0.2
Release:        9%{?dist}
Summary:        Kolab Object Handling Library

License:        LGPLv3+
URL:            http://git.kolab.org/libkolab

Source0:        http://mirror.kolabsys.com/pub/releases/libkolab-%{version}.tar.gz

BuildRequires:  boost-devel
BuildRequires:  libcurl-devel
BuildRequires:  libkolabxml-devel >= 1.1.1
BuildRequires:  python2-devel
BuildRequires:  swig
BuildRequires:  xerces-c-devel

# kf5
BuildRequires:  cmake(KF5CoreAddons)

# kde-apps
BuildRequires:  kf5-akonadi-notes-devel
BuildRequires:  kf5-akonadi-server-devel
BuildRequires:  kf5-kcalendarcore-devel
BuildRequires:  kf5-kcalendarutils-devel
BuildRequires:  kf5-kcontacts-devel
BuildRequires:  kf5-kmime-devel
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5CalendarCore)
BuildRequires:  cmake(KF5CalendarUtils)
BuildRequires:  cmake(KF5Mime)
BuildRequires:  cmake(KF5AkonadiNotes)

## tests
BuildRequires:  xorg-x11-server-Xvfb

%description
The libkolab library is an advanced library to  handle Kolab objects.

%package devel
Summary:        Kolab library development headers
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       libkolabxml-devel >= 1.1.1
## pretty sure these aren't needed, cascades these extra deps
## to kf5 pim -devel pkgs too -- rex
#Requires:       php-devel
#Requires:       python2-devel
%description devel
Development headers for the Kolab object libraries.

%if 0%{?with_php}
%package -n php-kolab
Summary:        PHP Bindings for libkolab
Requires:       %{name}%{?_isa} = %{version}-%{release}
BuildRequires:  php >= 5.3
BuildRequires:  php-devel >= 5.3
%if 0%{?rhel} > 5 || 0%{?fedora} > 15
Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
%else
Requires:       php-api = %{php_apiver}
%endif
%{!?php_inidir: %global php_inidir %{_sysconfdir}/php.d/}
%{!?php_extdir: %global php_extdir %{_libdir}/php/modules}
%{!?php_apiver: %global php_apiver  %((echo 0; php -i 2>/dev/null | sed -n 's/^PHP API => //p') | tail -1)}
%if "%{php_version}" < "5.6"
%global ini_name     kolab.ini
%else
%global ini_name     40-kolab.ini
%endif
%description -n php-kolab
PHP Bindings for libkolab
%endif

%package -n python2-kolab
Summary:        Python2 bindings for libkolab
Obsoletes:      python-kolab < 1.0.2
Provides:       python-kolab = %{version}-%{release}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python2-kolabformat >= 1.0.0
%description -n python2-kolab
Python2 bindings for libkolab


%prep
%setup -q -n libkolab-%{version}


%build
mkdir build
pushd build
%{cmake} .. \
%if 0%{?with_php}
    -DPHP_BINDINGS=ON \
    -DPHP_INSTALL_DIR=%{php_extdir} \
%endif
    -DPYTHON_BINDINGS=ON \
    -DPYTHON_INSTALL_DIR=%{python2_sitearch}
make
popd


%install
make install DESTDIR=%{buildroot} -C build

%if 0%{?with_php}
mkdir -p %{buildroot}%{_datadir}/php
mv %{buildroot}%{php_extdir}/*.php %{buildroot}/%{_datadir}/php/.

mkdir -p %{buildroot}%{php_inidir}
cat >%{buildroot}%{php_inidir}/%{ini_name} <<EOF
; Kolab libraries
extension=dummy.so
extension=kolabobject.so
extension=kolabshared.so
extension=kolabcalendaring.so
extension=kolabicalendar.so
EOF
%endif

touch %{buildroot}%{python2_sitearch}/kolab/__init__.py


%check
#dbus-launch --exit-with-session \
export CTEST_OUTPUT_ON_FAILURE=1
xvfb-run -a \
make test ARGS="--output-on-failure --timeout 10" -C build ||:


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_libdir}/libkolab.so.1*

%files devel
%{_libdir}/libkolab.so
%{_libdir}/cmake/Libkolab/
%{_includedir}/kolab/

%if 0%{?with_php}
%files -n php-kolab
%config(noreplace) %{php_inidir}/%{ini_name}
%{_datadir}/php/dummy.php
%{php_extdir}/dummy.so
%{_datadir}/php/kolabcalendaring.php
%{php_extdir}/kolabcalendaring.so
%{_datadir}/php/kolabicalendar.php
%{php_extdir}/kolabicalendar.so
%{_datadir}/php/kolabobject.php
%{php_extdir}/kolabobject.so
%{_datadir}/php/kolabshared.php
%{php_extdir}/kolabshared.so
%endif

%files -n python2-kolab
%{python2_sitearch}/kolab/


%changelog
* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 21 2017 Kalev Lember <klember@redhat.com> - 1.0.2-7
- Rebuilt for Boost 1.64

* Fri Jul 07 2017 Igor Gnatenko <ignatenko@redhat.com> - 1.0.2-6
- Rebuild due to bug in RPM (RHBZ #1468476)

* Thu Apr 13 2017 Rex Dieter <rdieter@fedoraproject.org> - 1.0.2-5
- -devel: drop Requires: python2-devel php-devel

* Wed Feb 08 2017 Kalev Lember <klember@redhat.com> - 1.0.2-4
- Rebuilt for Boost 1.63

* Mon Jan 16 2017 Rex Dieter <rdieter@fedoraproject.org> - 1.0.2-3
- rebuild (kde-apps-16.12), %%check: use xvfb-run

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Jun 28 2016 Rex Dieter <rdieter@fedoraproject.org> - 1.0.2-1
- libkolab-1.0.2

* Tue Feb 02 2016 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.5.3-5
- Rebuilt for boost-1.60.

* Sun Sep 13 2015 Rex Dieter <rdieter@fedoraproject.org> 0.5.3-4
- Rebuild (boost)

* Fri Jul 31 2015 Rex Dieter <rdieter@fedoraproject.org> 0.5.3-3
- explicitly BR: boost-devel

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 04 2015 Rex Dieter <rdieter@fedoraproject.org> 0.5.3-1
- 0.5.3

* Wed Feb 25 2015 Rex Dieter <rdieter@fedoraproject.org> 0.5.2-4
- rebuild (gcc5)

* Fri Feb 06 2015 Rex Dieter <rdieter@fedoraproject.org> 0.5.2-3
- rebuild (boost)

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jul 16 2014 Rex Dieter <rdieter@fedoraproject.org> 0.5.2-1
- 0.5.2

* Wed Jul 02 2014 Rex Dieter <rdieter@fedoraproject.org> - 0.5.1-1
- libkolab-0.5.1
- s/python-devel/python2-devel/, s/qt-devel/qt4-devel/

* Fri Jun 20 2014 Remi Collet <rcollet@redhat.com> - 0.5.0-4
- rebuild for https://fedoraproject.org/wiki/Changes/Php56
- add numerical prefix to extension configuration file

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 0.5.0-2
- rebuild for boost 1.55.0

* Mon Oct 14 2013 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.5.0-1
- New upstream release

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 28 2013 Petr Machata <pmachata@redhat.com> - 0.4.2-2
- Rebuild for boost 1.54.0

* Wed May 15 2013 Christoph Wickert <cwickert@fedoraproject.org> - 0.4.2-1
- Update to 0.4.2
- Fix build error with cmake 2.8.11

* Fri Mar 22 2013 Remi Collet <rcollet@redhat.com> - 0.4.1-4
- rebuild for http://fedoraproject.org/wiki/Features/Php55

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.4.1-3
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.4.1-2
- Rebuild for Boost-1.53.0

* Wed Jan  9 2013 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.4.1-1
- Update version to 0.4.1

* Tue Nov 20 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.4-0.1
- New upstream release
- Correct php.d/kolab.ini

* Wed Aug 15 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.3.1-3
- Fix build (patch1)
- Merge back with Fedora,
- Rebuilt for boost (Christoph Wickert, 0.3-10)

* Wed Aug  8 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.3.1-1
- New upstream version 0.3.1
- Correct locations and naming of PHP bindings modules

* Thu Aug  2 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.3-9
- New snapshot
- Ship PHP and Python bindings
- Conditionally build with libcalendaring
- Execute tests
- Correct installation directory for headers

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jun 26 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.3-5
- Fix some review issues (#833853)
- Rebuild after some packaging fixes (4)

* Sat Jun  9 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.3-3
- Check in latest snapshot

* Sat May 12 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.3-1
- Snapshot version after buildsystem changes

* Wed May  2 2012 Jeroen van Meeuwen <vanmeeuwen@kolabsys.com> - 0.2.0-1
- First package
